==> 1.12.0.zip: huesos/mirzaev/arming_bot/system/public/robot.php <==
<?php

declare(strict_types=1);

namespace mirzaev\arming_bot;

// Files of the project
use mirzaev\arming_bot\controllers\core as controller,
	mirzaev\arming_bot\models\core as model,
	mirzaev\arming_bot\models\telegram;

// Фреймворк Telegram
use Zanzara\Zanzara,
	Zanzara\Context,
	Zanzara\Config;

ini_set('error_reporting', E_ALL);
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);

// Версия робота
define('ROBOT_VERSION', '1.0.0');

// Путь до настроек
define('SETTINGS', __DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'settings');

// Путь до хранилища
define('STORAGE', __DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'storage');

// Файл в формате xlsx с примером excel-документа для импорта каталога
define('CATALOG_EXAMPLE', STORAGE . DIRECTORY_SEPARATOR . 'example.xlsx');

// Файл в формате xlsx для импорта каталога
define('CATALOG_IMPORT', STORAGE . DIRECTORY_SEPARATOR . 'import.xlsx');

/**
 * Ключ чат-робота Telegram 
 * @deprecated
 */
define('KEY', require(SETTINGS . DIRECTORY_SEPARATOR . 'telegram.php'));
define('TELEGRAM_KEY', require(SETTINGS . DIRECTORY_SEPARATOR . 'telegram.php'));

// Initialize dependencies
require __DIR__ . DIRECTORY_SEPARATOR
	. '..' . DIRECTORY_SEPARATOR
	. '..' . DIRECTORY_SEPARATOR
	. '..' . DIRECTORY_SEPARATOR
	. '..' . DIRECTORY_SEPARATOR
	. 'vendor' . DIRECTORY_SEPARATOR
	. 'autoload.php';

// Инициализация ядра контроллеров MINIMAL
new controller(false);

// Инициализация ядра моделей MINIMAL
new model(true);

$config = new Config();
$config->setParseMode(Config::PARSE_MODE_MARKDOWN);
$config->useReactFileSystem(true);

$bot = new Zanzara(TELEGRAM_KEY, $config);

/* $bot->onUpdate(function (Context $ctx): void {
	var_dump($ctx->getMessage()->getWebAppData());
	var_dump($ctx->getEffectiveUser() );
}); */

$bot->onCommand('start', fn($ctx) => telegram::start($ctx));
$bot->onCommand('contacts', fn($ctx) => telegram::contacts($ctx));
$bot->onCommand('company', fn($ctx) => telegram::company($ctx));
$bot->onCommand('community', fn($ctx) => telegram::community($ctx));
$bot->onCommand('settings', fn($ctx) => telegram::settings($ctx));

$bot->onText('💬 Контакты', fn($ctx) => telegram::contacts($ctx));
$bot->onText('🏛️ О компании', fn($ctx) => telegram::company($ctx));
$bot->onText('🎯 Сообщество', fn($ctx) => telegram::community($ctx));
$bot->onText('⚙️  Настройки', fn($ctx) => telegram::settings($ctx));

$bot->onCbQueryData(['mail'], fn($ctx) => telegram::_mail($ctx));
$bot->onCbQueryData(['import_request'], fn($ctx) => telegram::import_request($ctx));
$bot->onCbQueryData(['tuning'], fn($ctx) => telegram::tuning($ctx));
$bot->onCbQueryData(['brands'], fn($ctx) => telegram::brands($ctx));

// Инициализация middleware с обработкой аккаунта
$bot->middleware([telegram::class, "account"]);

// Инициализация middleware с обработкой технических работ разных уровней
$bot->middleware([telegram::class, "suspension"]);

// Запуск чат-робота
$bot->run();

==> 1.13.0.zip: huesos/mirzaev/arming_bot/system/public/robot.php <==
<?php

declare(strict_types=1);

namespace mirzaev\arming_bot;

// Files of the project
use mirzaev\arming_bot\controllers\core as controller,
	mirzaev\arming_bot\models\core as model,
	mirzaev\arming_bot\models\cart,
	mirzaev\arming_bot\models\telegram;

// Framework for Telegram
use Zanzara\Zanzara,
	Zanzara\Context,
	Zanzara\Config;

ini_set('error_reporting', E_ALL ^ E_DEPRECATED);
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);

// Версия робота
define('ROBOT_VERSION', '1.0.0');

// Путь до настроек
define('SETTINGS', __DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'settings');

// Путь до хранилища
define('STORAGE', __DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'storage');

// Файл в формате xlsx с примером excel-документа для импорта каталога
define('CATALOG_EXAMPLE', STORAGE . DIRECTORY_SEPARATOR . 'example.xlsx');

// Файл в формате xlsx для импорта каталога
define('CATALOG_IMPORT', STORAGE . DIRECTORY_SEPARATOR . 'import.xlsx');

/**
 * Ключ чат-робота Telegram 
 * @deprecated
 */
define('KEY', require(SETTINGS . DIRECTORY_SEPARATOR . 'telegram.php'));
define('TELEGRAM_KEY', require(SETTINGS . DIRECTORY_SEPARATOR . 'telegram.php'));

// Initialize dependencies
require __DIR__ . DIRECTORY_SEPARATOR
	. '..' . DIRECTORY_SEPARATOR
	. '..' . DIRECTORY_SEPARATOR
	. '..' . DIRECTORY_SEPARATOR
	. '..' . DIRECTORY_SEPARATOR
	. 'vendor' . DIRECTORY_SEPARATOR
	. 'autoload.php';

// Инициализация ядра контроллеров MINIMAL
/* new controller(new core, false); */

// Инициализация ядра моделей MINIMAL
new model(true);

$config = new Config();
$config->setParseMode(Config::PARSE_MODE_MARKDOWN);
$config->useReactFileSystem(true);

$bot = new Zanzara(TELEGRAM_KEY, $config);

$bot->onUpdate(function (Context $ctx): void {
	// Initializing 'web app" data
	$app = $ctx->getMessage()?->getWebAppData();

	if (!empty($app)) {
		// Initialized "web app" data

		// Initializing request from "web app" data
		$request = json_decode($app->getData(), false, 10);

		if ($request->type === 'cart_share') {
			// Cart attaching

			// Attaching cart to the Telegram account
			telegram::cart_attach($ctx, $request->hash, $request->delivery);
		}
	}

	unset($app);
});

$bot->onCommand('start', fn($ctx) => telegram::start($ctx));
$bot->onCommand('contacts', fn($ctx) => telegram::contacts($ctx));
$bot->onCommand('company', fn($ctx) => telegram::company($ctx));
$bot->onCommand('community', fn($ctx) => telegram::community($ctx));
$bot->onCommand('settings', fn($ctx) => telegram::settings($ctx));

$bot->onText('💬 Контакты', fn($ctx) => telegram::contacts($ctx));
$bot->onText('🏛️ О компании', fn($ctx) => telegram::company($ctx));
$bot->onText('🎯 Сообщество', fn($ctx) => telegram::community($ctx));
$bot->onText('⚙️  Настройки', fn($ctx) => telegram::settings($ctx));

$bot->onCbQueryData(['mail'], fn($ctx) => telegram::_mail($ctx));
$bot->onCbQueryData(['import_request'], fn($ctx) => telegram::import_request($ctx));
$bot->onCbQueryData(['tuning'], fn($ctx) => telegram::tuning($ctx));
$bot->onCbQueryData(['brands'], fn($ctx) => telegram::brands($ctx));

$bot->onException(function (Context $ctx, $exception) {
	var_dump($exception);
});

// Инициализация middleware с обработкой аккаунта
$bot->middleware([telegram::class, "account"]);

// Инициализация middleware с обработкой технических работ разных уровней
$bot->middleware([telegram::class, "suspension"]);

// Запуск чат-робота
$bot->run();
